@@ -22,28 +22,29 @@ NaiveBayes.formula <- function (formula, data, ..., subset, na.action = na.pass)
 }
 
 
-NaiveBayes.default <- function (x, grouping, prior = NULL, usekernel = FALSE, ...) 
+NaiveBayes.default <- function (x, grouping, prior = NULL, usekernel = FALSE, fL = 0, ...) 
 {
     x <- data.frame(x)
-    if (is.null(prior)) apriori <- table(grouping) / length(grouping)
-    else apriori <- as.table(prior / sum(prior))
+    if (is.null(prior)) 
+        apriori <- table(grouping) / length(grouping)
+    else 
+        apriori <- as.table(prior / sum(prior))
     call <- match.call()
-    #Yname <- deparse(substitute(grouping))
     Yname<- "grouping"
-    est <- function(var) 
-      if(is.numeric(var)) {
-        if (usekernel)
-            lapply(split(var, grouping), FUN = function(xx) density(xx, ...))
-        else
-            cbind(tapply(var, grouping, mean), tapply(var, grouping, sd))
-      }
-    else {
-        tab <- table(grouping, var)
-        tab / rowSums(tab)
+    LaplaceEst <- function(x, f = 0)  
+        t(apply(x, 1, function(u) (u + f)/(sum(u) + (length(u) * f))))
+        
+    est <- function(var){
+        if(is.numeric(var)) {
+            if (usekernel)
+                lapply(split(var, grouping), FUN = function(xx) density(xx, ...))
+            else
+                cbind(tapply(var, grouping, mean), tapply(var, grouping, sd))
+        } 
+        else LaplaceEst(table(grouping, var), f = fL)
     }
+    
     tables <- lapply(x, est)
-    #for (i in 1:length(tables)) 
-    #    {names(dimnames(tables[[i]])) <- c(Yname, colnames(x)[i])}
     names(dimnames(apriori)) <- Yname
     structure(list(apriori = apriori, tables = tables, levels = levels(grouping), 
         call = call, x = x, usekernel = usekernel, varnames = colnames(x)), 
